@@ -131,7 +131,7 @@ summary.forecast <- function(object,...)
 #    cat(paste("\n\nCall:\n",deparse(object$call)))
     cat(paste("\n\nModel Information:\n"))
     print(object$model)
-    cat("\nTraining set error measures:\n")
+    cat("\nError measures:\n")
     print(accuracy(object))
     if(is.null(object$mean))
         cat("\n No forecasts\n")
@@ -154,7 +154,8 @@ plotlmforecast <- function(object, plot.conf, shaded, shadecols, col, fcol, pi.c
     xlim <- range(object$newdata[,xvar],model.frame(object$model)[,xvar])
   if(is.null(ylim))
     ylim <- range(object$upper,object$lower,fitted(object$model)+residuals(object$model))
-  plot(formula(object$model),xx=model.frame(object$model),xlim=xlim,ylim=ylim,xlab=xlab,ylab=ylab,main=main,col=col,...)
+  plot(formula(object$model),data=model.frame(object$model), 
+    xlim=xlim,ylim=ylim,xlab=xlab,ylab=ylab,main=main,col=col,...)
   abline(object$model)
   nf <- length(object$mean)
   if(plot.conf)
